/* 
 * Copyright (C) 2001-2012 Michael Fuchs
 *
 * This file is part of herold.
 * 
 * herold is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * herold is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with herold.  If not, see <http://www.gnu.org/licenses/>.  
 */
package org.dbdoclet.trafo.tag.html;

import java.util.HashMap;

import org.dbdoclet.xiphias.dom.TextImpl;

abstract public class BlockElement extends HtmlElement {

    @Override
    protected boolean validate(HashMap<String, HashMap<String, String>> validParentMap) {

	if (validParentMap == null) {

	    throw new IllegalArgumentException("Parameter validParentMap is null!");
	}

	if (getParentNode() == null) {

	    throw new NullPointerException("Variable getParent() is null!");
	}

	if (nodeStack == null) {

	    throw new NullPointerException("Variable nodeStack is null!");
	}

	nodeStack.removeAllElements();
	nodeStack.push(this);

	if (validParentMap.get(getParentNode().getNodeName()) != null) {
	    return true;
	}

	if (getParentNode() instanceof Fieldset) {

	    getParentNode().getFirstChild();

	    if (!(getParentNode() instanceof Legend)) {

		Legend legend = new Legend();
		getParentNode().appendChild(legend);

		legend.appendChild(new TextImpl("Legend", legend));
	    }

	    return true;
	}

	if (getParentNode() instanceof Select) {

	    nodeStack.removeAllElements();

	    Option option = new Option();
	    nodeStack.push(option);

	    return true;
	}

	if (getParentNode() instanceof Optgroup) {

	    nodeStack.removeAllElements();

	    Option option = new Option();
	    nodeStack.push(option);

	    return true;
	}

	if (getParentNode() instanceof Dl) {

	    Dd dd = new Dd();
	    dd.appendChild(this);

	    nodeStack.push(dd);

	    return true;
	}

	if (getParentNode() instanceof Dir || getParentNode() instanceof Menu || getParentNode() instanceof Ol
		|| getParentNode() instanceof Ul) {

	    Li li = new Li();
	    li.appendChild(this);

	    nodeStack.push(li);

	    return true;
	}

	if (getParentNode() instanceof Table) {

	    Tr tr = new Tr();
	    Td td = new Td();
	    tr.appendChild(td);
	    td.appendChild(this);

	    nodeStack.push(td);
	    nodeStack.push(tr);

	    return true;
	}

	if (getParentNode() instanceof Tbody || getParentNode() instanceof Tfoot
		|| getParentNode() instanceof Thead) {

	    Tr tr = new Tr();
	    Td td = new Td();
	    tr.appendChild(td);
	    td.appendChild(this);

	    nodeStack.push(td);
	    nodeStack.push(tr);

	    return true;
	}

	if (getParentNode() instanceof Tr) {

	    Td td = new Td();
	    td.appendChild(this);

	    nodeStack.push(td);

	    return true;
	}

	if (getParentNode() instanceof Map) {

	    Div div = new Div();
	    div.appendChild(this);

	    nodeStack.push(div);

	    return true;
	}

	return false;
    }
}
