/* 
 * Copyright (C) 2001-2012 Michael Fuchs
 *
 * This file is part of herold.
 * 
 * herold is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * herold is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with herold.  If not, see <http://www.gnu.org/licenses/>.  
 */
package org.dbdoclet.trafo.tag.html;

import java.util.HashMap;

import org.dbdoclet.xiphias.dom.NodeImpl;

public class Tr extends StrictElement {

    private static String tagName = "tr";
    private static HashMap<String, HashMap<String, String>> validParentMap;
    static {

        validParentMap = new HashMap<String, HashMap<String, String>>();
        validParentMap.put(Table.getTag(), HtmlElement.getAttributeMap());
        validParentMap.put(Tbody.getTag(), HtmlElement.getAttributeMap());
        validParentMap.put(Thead.getTag(), HtmlElement.getAttributeMap());
        validParentMap.put(Tfoot.getTag(), HtmlElement.getAttributeMap());
    }

    public static String getTag() {

        return tagName;
    }

    public Tr() {

        setNodeName(tagName);
        setFormatType(FORMAT_BLOCK);
    }

    @Override
    public void closed() {

        boolean hasColumns = false;

        if (hasChildNodes() == true && getNumberOfChildNodes() > 0) {

            for (NodeImpl node : getTrafoChildNodes()) {

                if (node instanceof HtmlElement) {

                    HtmlElement elem = (HtmlElement) node;

                    if (elem instanceof TableColumnElement) {
                        hasColumns = true;
                    }
                }
            }
        }

        if (hasColumns == false) {

            appendChild(new Td());
        }
    }

    @Override
    public void init() {

    }

    @Override
    public boolean validate() {

        if (validate(validParentMap)) {
            return true;
        }

        return false;
    }

    @Override
    public boolean validateAttributes() {

        String valign = getAttribute("valign");

        if (valign != null) {

            if (valign.equalsIgnoreCase("top") == false && valign.equalsIgnoreCase("middle") == false
                    && valign.equalsIgnoreCase("bottom") == false && valign.equalsIgnoreCase("baseline") == false) {

                setAttribute("valign", "middle");
            }
        }

        return true;
    }

	public Integer getHeight() {
		return getIntAttribute("height");
	}
}
